==============
Components
==============

This tutorial describes the main components of zfit in more depths. For a brief overview, see also

zfit general
============


Variables
=========

.. toctree::
    :maxdepth: 1

    intro/space
    intro/parameter

Data
====

.. toctree::
    :maxdepth: 1

    intro/data

Model
=====

.. toctree::
    :maxdepth: 1

    intro/model

The following tutorials can also be found in
`zfit tutorials as Jupyter Notebooks. <https://github.com/zfit/zfit-tutorials>`_

.. toctree::
    :maxdepth: 1

    ../../../_tmp/zfit-tutorials/components/20 - Composite Models.ipynb
    ../../../_tmp/zfit-tutorials/components/60 - Custom PDF.ipynb
    ../../../_tmp/zfit-tutorials/components/62 - Multidim Custom PDF.ipynb



Loss
====

.. toctree::
    :maxdepth: 1

    intro/loss

Minimizer
=========

.. toctree::
    :maxdepth: 1

    intro/minimizer

Result
======

.. toctree::
    :maxdepth: 1

    intro/result

Statistical Inference
======================

.. toctree::
    :maxdepth: 1

    intro/toy_studies
